==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/it.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informazioni CPU non disponibili",
    "Load average" : "Carico medio",
    "Last minute" : "Ultimo minuto",
    "Memory info not available" : "Informazioni memoria non disponibili",
    "Total" : "Totale",
    "Current usage" : "Utilizzo attuale",
    "Users" : "Utenti",
    "Groups" : "Gruppi",
    "Links" : "Collegamenti",
    "Federated sent" : "Federati inviati",
    "Federated received" : "Federati ricevuti",
    "Last 24 hours" : "Ultime 24 ore",
    "Last 1 hour" : "Ultima ora",
    "Last 5 mins" : "Ultimi 5 minuti",
    "Copy" : "Copia",
    "Copied!" : "Copiati!",
    "Not supported!" : "Non supportato!",
    "Press ⌘-C to copy." : "Premi ⌘-C per copiare.",
    "Press Ctrl-C to copy." : "Premi Ctrl-C per copiare.",
    "Monitoring" : "Monitoraggio",
    "Monitoring app with useful server information" : "Applicazione di monitoraggio con informazioni utili sul server",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornisce informazioni utili sul server, come carico della CPU, utilizzo della memoria, utilizzo del disco, numero di utenti, ecc.",
    "CPU load" : "Carico CPU",
    "Memory usage" : "Utilizzo della memoria",
    "Active users" : "Utenti attivi",
    "Shares" : "Condivisioni",
    "Storage" : "Archiviazione",
    "Users:" : "Utenti:",
    "Files:" : "File:",
    "Storages:" : "Archiviazioni:",
    "Free Space:" : "Spazio libero:",
    "Nextcloud" : "Nextcloud",
    "Version:" : "Versione:",
    "Apps installed:" : "Applicazioni installate:",
    "Apps updates available:" : "Aggiornamenti applicazioni disponibili:",
    "PHP" : "PHP",
    "Memory Limit:" : "Limite memoria:",
    "Max Execution Time:" : "Tempo massimo di esecuzione:",
    "Upload max size:" : "Dimensione massima caricamento:",
    "Database" : "Database",
    "Type:" : "Tipo:",
    "Size:" : "Dimensione:",
    "External monitoring tool" : "Strumento di controllo esterno",
    "You can connect an external monitoring tool by using this end point:" : "Puoi collegare uno strumento di controllo esterno utilizzando questo terminatore: ",
    "Did you know?" : "Sapevi che?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "L'aggiunta di \"?format=json\" alla fine dell'UR restituisce il risultato in formato JSON!",
    "You can connect an external monitoring tool by using this end point: " : "Puoi collegare uno strumento di controllo esterno utilizzando questo terminatore: "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/it.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informazioni CPU non disponibili",
    "Load average" : "Carico medio",
    "Last minute" : "Ultimo minuto",
    "Memory info not available" : "Informazioni memoria non disponibili",
    "Total" : "Totale",
    "Current usage" : "Utilizzo attuale",
    "Users" : "Utenti",
    "Groups" : "Gruppi",
    "Links" : "Collegamenti",
    "Mails" : "Messaggi di posta",
    "Federated sent" : "Federati inviati",
    "Federated received" : "Federati ricevuti",
    "Talk conversations" : "Conversazioni di Talk",
    "Last 24 hours" : "Ultime 24 ore",
    "Last 1 hour" : "Ultima ora",
    "Last 5 mins" : "Ultimi 5 minuti",
    "Copy" : "Copia",
    "Copied!" : "Copiati!",
    "Not supported!" : "Non supportato!",
    "Press ⌘-C to copy." : "Premi ⌘-C per copiare.",
    "Press Ctrl-C to copy." : "Premi Ctrl-C per copiare.",
    "Monitoring" : "Monitoraggio",
    "Monitoring app with useful server information" : "Applicazione di monitoraggio con informazioni utili sul server",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornisce informazioni utili sul server, come carico della CPU, utilizzo della memoria, utilizzo del disco, numero di utenti, ecc.",
    "CPU load" : "Carico CPU",
    "Memory usage" : "Utilizzo della memoria",
    "Active users" : "Utenti attivi",
    "Shares" : "Condivisioni",
    "Storage" : "Archiviazione",
    "Users:" : "Utenti:",
    "Files:" : "File:",
    "Storages:" : "Archiviazioni:",
    "Free Space:" : "Spazio libero:",
    "Nextcloud" : "Nextcloud",
    "Version:" : "Versione:",
    "Apps installed:" : "Applicazioni installate:",
    "Apps updates available:" : "Aggiornamenti applicazioni disponibili:",
    "PHP" : "PHP",
    "Memory Limit:" : "Limite memoria:",
    "Max Execution Time:" : "Tempo massimo di esecuzione:",
    "Upload max size:" : "Dimensione massima caricamento:",
    "Database" : "Database",
    "Type:" : "Tipo:",
    "Size:" : "Dimensione:",
    "External monitoring tool" : "Strumento di controllo esterno",
    "You can connect an external monitoring tool by using this end point:" : "Puoi collegare uno strumento di controllo esterno utilizzando questo terminatore: ",
    "Did you know?" : "Sapevi che?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "L'aggiunta di \"?format=json\" alla fine dell'UR restituisce il risultato in formato JSON!"
},
"nplurals=2; plural=(n != 1);");
